==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicColorChooserUI__24PreviewListener.h <==
// class javax.swing.plaf.basic.BasicColorChooserUI$PreviewListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf505b6fbe17bf03 javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener_H_
#define _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vmethods	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtable	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$method$_init$5fea946ba5b0bc9f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$method$_init$0f04f2249340331d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vmethods	javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$refs {
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_refs	javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_nonrefs	javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object {
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicColorChooserUI__24PreviewListener.h <==
// class javax.swing.plaf.basic.BasicColorChooserUI$PreviewListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8666545df506d439 javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener_H_
#define _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vmethods	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtable	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$method$_init$5fea946ba5b0bc9f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$method$_init$0f04f2249340331d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vmethods	javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$refs {
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_refs	javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$sub_nonrefs	javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$object {
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$vtype _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PreviewListener_H_ */
